Metadata
--------

Extraction
^^^^^^^^^^

.. automodule:: cesard.metadata.extract
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        calc_enl
        calc_performance_estimates
        evaluate_types
        geometry_from_vec
        get_header_size
        vec_from_srccoords

XML
^^^

.. automodule:: cesard.metadata.xml
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        parse
        product_xml
        source_xml

STAC
^^^^

.. automodule:: cesard.metadata.stac
    :members:
    :undoc-members:
    :show-inheritance:

    .. autosummary::
        :nosignatures:

        parse
        product_json
        source_json